@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.5.1'
+nodeenv_version = '0.5.2'
 
 import sys
 import os
@@ -242,14 +242,24 @@ def callit(cmd, show_stdout=True, in_shell=False,
 
     # error handler
     if proc.returncode:
-        for s in all_output:
-            logger.critical(s)
+        if show_stdout:
+            for s in all_output:
+                logger.critical(s)
         raise OSError("Command %s failed with error code %s"
             % (cmd_desc, proc.returncode))
 
     return proc.returncode, all_output
 
 
+def get_node_src_url(version, postfix=''):
+    node_name = 'node-v%s%s' % (version, postfix)
+    tar_name = '%s.tar.gz' % (node_name)
+    if version > "0.5.0":
+        node_url = 'http://nodejs.org/dist/v%s/%s' % (version, tar_name)
+    else:
+        node_url = 'http://nodejs.org/dist/%s' % (tar_name)
+    return node_url
+
 # ---------------------------------------------------------
 # Virtual environment functions
 
@@ -258,15 +268,12 @@ def install_node(env_dir, src_dir, opt):
     Download source code for node.js, unpack it
     and install it in virtual environment.
     """
-    logger.info(' * Install node.js (%s) ' % opt.node,
+    logger.info(' * Install node.js (%s' % opt.node,
                          extra=dict(continued=True))
 
     node_name = 'node-v%s' % (opt.node)
     tar_name = '%s.tar.gz' % (node_name)
-    if opt.node > "0.5.0":
-        node_url = 'http://nodejs.org/dist/v%s/%s' % (opt.node, tar_name)
-    else:
-        node_url = 'http://nodejs.org/dist/%s' % (tar_name)
+    node_url = get_node_src_url(opt.node)
     node_tar = join(src_dir, tar_name)
     node_src_dir = join(src_dir, node_name)
     env_dir = abspath(env_dir)
@@ -283,7 +290,16 @@ def install_node(env_dir, src_dir, opt):
     cmd.append('-')
     cmd.append('-C')
     cmd.append(src_dir)
-    callit(cmd, opt.verbose, True, env_dir)
+    try:
+        callit(cmd, opt.verbose, True, env_dir)
+        logger.info(') ', extra=dict(continued=True))
+    except OSError:
+        postfix = '-RC1'
+        logger.info('%s) ' % postfix, extra=dict(continued=True))
+        new_node_url = get_node_src_url(opt.node, postfix)
+        cmd[cmd.index(node_url)] = new_node_url
+        callit(cmd, opt.verbose, True, env_dir)
+
     logger.info('.', extra=dict(continued=True))
 
     env = {'JOBS': str(opt.jobs)}
